/**
 * @file
 */

(function (Drupal, drupalSettings) {
    'use strict';
    Drupal.behaviors.handsontablecsv = {
        attach: function (context, settings) {
            let renderedTables = document.querySelectorAll('.rendered-table.format-csv');

            renderedTables.forEach(function (renderedTable) {
                if (renderedTable.classList.contains('is-loaded')) {
                  return;
                }

                let textarea = renderedTable.parentElement.querySelector('input[type="hidden"]');
                let textAreaValue = textarea.value;
                let textAreaHtml = textarea.innerHTML;

                if ((textAreaValue.length > 0) && (textAreaHtml === '')) {
                    let data = Papa.parse(textAreaValue).data;
                    let table = new Handsontable(renderedTable, {
                        data: data,
                        stretchH: 'all',
                        licenseKey: drupalSettings?.handsontable?.license_key ?? "",
                        autoWrapRow: true,
                        contextMenu: {
                          items: {
                            'row_above': {
                              "name": Drupal.t('Insert row above'),
                            },
                            'row_below': {
                              "name": Drupal.t('Insert row below'),
                            },
                            'hsep1': "---------",
                            'col_left': {
                              "name": Drupal.t('Insert column on the left'),
                            },
                            'col_right': {
                              "name": Drupal.t('Insert column on the right'),
                            },
                            'hsep2': '---------',
                            'remove_row': {
                              "name": Drupal.t('Remove row'),
                            },
                            'remove_col': {
                              "name": Drupal.t('Remove column'),
                            },
                            'hsep3': '---------',
                            'undo': {
                              "name": Drupal.t('Undo'),
                            },
                            'redo': {
                              "name": Drupal.t('Redo'),
                            },
                            'hsep4': "---------",
                            'cut': {
                              "name": Drupal.t('Cut'),
                            },
                            'copy': {
                              "name": Drupal.t('Copy'),
                            },
                          }
                        },
                    });
                    table.updateSettings({
                        afterChange: function (e) {
                          textarea.value = Papa.unparse(table.getData());
                        },
                        afterCreateRow: function (index,amount) {
                          textarea.value = Papa.unparse(table.getData());
                        },
                        afterRemoveCol: function (index,amount) {
                          textarea.value = Papa.unparse(table.getData());
                        },
                        afterRowMove: function (index,amount) {
                          textarea.value = Papa.unparse(table.getData());
                        },
                        afterRemoveRow: function (index,amount) {
                          textarea.value = Papa.unparse(table.getData());
                        },
                        afterCreateCol: function (index,amount) {
                          textarea.value = Papa.unparse(table.getData());
                        }
                    });
                }

                renderedTable.classList.add('is-loaded');
            });

        }
    };

})(Drupal, drupalSettings);
