/**
 * @file
 */

(function (Drupal, drupalSettings) {
    'use strict';
    Drupal.behaviors.handsontablejson = {
        attach: function (context, settings) {

            let renderedTables = document.querySelectorAll('.rendered-table.format-json');

            renderedTables.forEach(function (renderedTable) {
                if (renderedTable.classList.contains('is-loaded')) {
                  return;
                }

                let renderedTableParent = renderedTable.parentElement;
                let textarea = renderedTableParent.querySelector('input[type="hidden"]');
                let textAreaValue = textarea.value;
                let textAreaHtml = textarea.innerHTML;

                if ((textAreaValue.length > 0) && (textAreaHtml === '')) {
                    let config = renderedTableParent.querySelector('.table-config');
                    let rows = 1;
                    let columns = 2;

                    if (config !== null
                        && (config.value.length > 0)) {
                        config = JSON.parse(config.value);
                        rows = config.rows !== undefined ? config.rows : 1;
                        columns = config.columns !== undefined ? config.columns : 2;
                        config = config.value;
                    }
                    let data = JSON.parse(textAreaValue);
                    let header = data[0];
                    let table = new Handsontable(renderedTable, {
                        data: data,
                        cells: function (row, col, prop) {
                            var cellProperties = {};
                            if (config !== null && config[row] !== undefined && config[row][col] !== undefined) {
                                cellProperties.placeholder = config[row][col];
                            }

                            return cellProperties;
                        },
                        minRows: rows,
                        minCols: columns,
                        stretchH: 'all',
                        licenseKey: drupalSettings?.handsontable?.license_key ?? "",
                        autoWrapRow: true,
                        contextMenu: {
                          items: {
                            'row_above': {
                              "name": Drupal.t('Insert row above'),
                            },
                            'row_below': {
                              "name": Drupal.t('Insert row below'),
                            },
                            'hsep1': "---------",
                            'col_left': {
                              "name": Drupal.t('Insert column on the left'),
                            },
                            'col_right': {
                              "name": Drupal.t('Insert column on the right'),
                            },
                            'hsep2': '---------',
                            'remove_row': {
                              "name": Drupal.t('Remove row'),
                            },
                            'remove_col': {
                              "name": Drupal.t('Remove column'),
                            },
                            'hsep3': '---------',
                            'undo': {
                              "name": Drupal.t('Undo'),
                            },
                            'redo': {
                              "name": Drupal.t('Redo'),
                            },
                            'hsep4': "---------",
                            'cut': {
                              "name": Drupal.t('Cut'),
                            },
                            'copy': {
                              "name": Drupal.t('Copy'),
                            },
                          }
                        },
                    });

                    table.updateSettings({
                        afterChange: function (e) {
                          textarea.value = JSON.stringify(table.getData());
                        },
                        afterCreateRow: function (index, amount) {
                          textarea.value = JSON.stringify(table.getData());
                        },
                        afterRemoveCol: function (index, amount) {
                          textarea.value = JSON.stringify(table.getData());
                        },
                        afterRowMove: function (index, amount) {
                          textarea.value = JSON.stringify(table.getData());
                        },
                        afterRemoveRow: function (index, amount) {
                          textarea.value = JSON.stringify(table.getData());
                        },
                        afterCreateCol: function (index, amount) {
                          textarea.value = JSON.stringify(table.getData());
                        }
                    });
                }

                renderedTable.classList.add('is-loaded');
            });

        }
    };

})(Drupal, drupalSettings);
